# Data Structures for N-Tier Applications

N-Tier is a library containing common data structures and classes used in
making the domain layer of n-tier web applications.

Please note: documentation on this project is currently not provided

## Running tests:

`python -m tests`

or

`coverage run -m tests && coverage report`
